@@ -15,12 +15,14 @@ from . import timeseries_property_data
 from . import timeseries_data
 from . import event_categories
 from . import events
+from . import event_categories_by_users
 from . import timeseries_by_events
 from . import events_by_sites
 from . import events_by_buildings
 from . import events_by_storeys
 from . import events_by_spaces
 from . import events_by_zones
+from . import notifications
 from . import sites
 from . import buildings
 from . import storeys
@@ -68,6 +70,7 @@ MODULES = (
     timeseries_property_data,
     timeseries_data,
     event_categories,
+    event_categories_by_users,
     events,
     timeseries_by_events,
     events_by_sites,
@@ -75,6 +78,7 @@ MODULES = (
     events_by_storeys,
     events_by_spaces,
     events_by_zones,
+    notifications,
     sites,
     buildings,
     storeys,
